# eric7.Preferences.ConfigurationPages.ViewmanagerPage

Module implementing the Viewmanager configuration page.

### Global Attributes

None

### Classes

ViewmanagerPage | Class implementing the Viewmanager configuration page.

### Functions

create | Module function to create the configuration page.

## ViewmanagerPage

Class implementing the Viewmanager configuration page.

### Derived from

ConfigurationPageBase, Ui_ViewmanagerPage

### Class Attributes

None

### Class Methods

None

### Methods

ViewmanagerPage | Constructor
on_windowComboBox_activated | Private slot to show a preview of the selected workspace view type.
save | Public slot to save the Viewmanager configuration.

### Static Methods

None

#### ViewmanagerPage (Constructor)

ViewmanagerPage()

Constructor

#### ViewmanagerPage.on_windowComboBox_activated

on_windowComboBox_activated(index)

Private slot to show a preview of the selected workspace view type.

index
  index of selected workspace view type (integer)

#### ViewmanagerPage.save

save()

Public slot to save the Viewmanager configuration.

Up

## create

create(dlg)

Module function to create the configuration page.

dlg
  reference to the configuration dialog

Return:
  reference to the instantiated page (ConfigurationPageBase)

Up